@@ -19,8 +19,7 @@ import functools
 
 
 class GitlabError(Exception):
-    def __init__(self, error_message="", response_code=None,
-                 response_body=None):
+    def __init__(self, error_message="", response_code=None, response_body=None):
 
         Exception.__init__(self, error_message)
         # Http status code
@@ -28,7 +27,12 @@ class GitlabError(Exception):
         # Full http response
         self.response_body = response_body
         # Parsed error message from gitlab
-        self.error_message = error_message
+        try:
+            # if we receive str/bytes we try to convert to unicode/str to have
+            # consistent message types (see #616)
+            self.error_message = error_message.decode()
+        except Exception:
+            self.error_message = error_message
 
     def __str__(self):
         if self.response_code is not None:
@@ -153,6 +157,14 @@ class GitlabUnblockError(GitlabOperationError):
     pass
 
 
+class GitlabDeactivateError(GitlabOperationError):
+    pass
+
+
+class GitlabActivateError(GitlabOperationError):
+    pass
+
+
 class GitlabSubscribeError(GitlabOperationError):
     pass
 
@@ -165,6 +177,14 @@ class GitlabMRForbiddenError(GitlabOperationError):
     pass
 
 
+class GitlabMRApprovalError(GitlabOperationError):
+    pass
+
+
+class GitlabMRRebaseError(GitlabOperationError):
+    pass
+
+
 class GitlabMRClosedError(GitlabOperationError):
     pass
 
@@ -225,6 +245,10 @@ class GitlabRepairError(GitlabOperationError):
     pass
 
 
+class GitlabRevertError(GitlabOperationError):
+    pass
+
+
 class GitlabLicenseError(GitlabOperationError):
     pass
 
@@ -239,6 +263,7 @@ def on_http_error(error):
         error(Exception): The exception type to raise -- must inherit from
             GitlabError
     """
+
     def wrap(f):
         @functools.wraps(f)
         def wrapped_f(*args, **kwargs):
@@ -246,5 +271,7 @@ def on_http_error(error):
                 return f(*args, **kwargs)
             except GitlabHttpError as e:
                 raise error(e.error_message, e.response_code, e.response_body)
+
         return wrapped_f
+
     return wrap
